import { BaseClient } from "./baseClient.js";
import type { GetStudentCodeOptions, GetStudentCodeResponse, RewardPurchaseResponse, RewardsResponse } from "../types.js";
/**
 * Student Client.
 * See {@link BaseClient} for all shared methods.
 *
 * @example
 * ```ts
 * import { StudentClient } from "classcharts-api";
 * // Date of birth MUST in the format DD/MM/YYYY
 * const client = new StudentClient("classchartsCode", "01/01/2000");
 * await client.login();
 * ```
 */
export declare class StudentClient extends BaseClient {
    /**
     * ClassCharts student code
     */
    private studentCode;
    /**
     * Student's date of birth
     */
    private dateOfBirth;
    /**
     * @param studentCode ClassCharts student code
     * @param dateOfBirth Student's date of birth
     */
    constructor(studentCode: string, dateOfBirth?: string);
    /**
     * Authenticates with ClassCharts
     */
    login(): Promise<void>;
    /**
     * Gets the available items in the current student's rewards shop
     * @returns Array of purchasable items
     */
    getRewards(): Promise<RewardsResponse>;
    /**
     * Purchase a reward item from the current student's rewards shop
     * @param itemId number
     * @returns An object containing the current student's balance and item ID purchased
     */
    purchaseReward(itemId: number): Promise<RewardPurchaseResponse>;
    /**
     * Gets the current student's student code
     * @param options GetStudentCodeOptions
     * @param options.dateOfBirth Date of birth in the format YYYY-MM-DD
     * @returns
     */
    getStudentCode(options: GetStudentCodeOptions): Promise<GetStudentCodeResponse>;
}
//# sourceMappingURL=studentClient.d.ts.map