import type { ChangePasswordResponse, GetPupilsResponse } from "../types.js";
import { BaseClient } from "./baseClient.js";
/**
 * Parent Client.
 * See {@link BaseClient} for all shared methods.
 *
 * @example
 * ```ts
 * import { ParentClient } from "classcharts-api";
 * const client = new ParentClient("username", "password");
 * await client.login();
 * ```
 */
export declare class ParentClient extends BaseClient {
    private password;
    private email;
    pupils: GetPupilsResponse;
    /**
     * @param email Parent's email address
     * @param password Parent's password
     */
    constructor(email: string, password: string);
    /**
     * Authenticates with ClassCharts
     */
    login(): Promise<void>;
    /**
     * Get a list of pupils connected to this parent's account
     * @returns an array of Pupils connected to this parent's account
     */
    getPupils(): Promise<GetPupilsResponse>;
    /**
     * Selects a pupil to be used with API requests
     * @param pupilId Pupil ID obtained from this.pupils or getPupils()
     *
     * @see getPupils
     */
    selectPupil(pupilId: number): void;
    /**
     * Changes the login password for the current parent account
     * @param currentPassword Current password
     * @param newPassword New password
     * @returns Whether the request was successful
     */
    changePassword(currentPassword: string, newPassword: string): Promise<ChangePasswordResponse>;
}
//# sourceMappingURL=parentClient.d.ts.map